summaryrefslogtreecommitdiffstats
path: root/kivio/kiviopart/kiviosdk/kivio_shape_data.h
diff options
context:
space:
mode:
Diffstat (limited to 'kivio/kiviopart/kiviosdk/kivio_shape_data.h')
-rw-r--r--kivio/kiviopart/kiviosdk/kivio_shape_data.h54
1 files changed, 27 insertions, 27 deletions
diff --git a/kivio/kiviopart/kiviosdk/kivio_shape_data.h b/kivio/kiviopart/kiviosdk/kivio_shape_data.h
index 1c386055..f97e5ec9 100644
--- a/kivio/kiviopart/kiviosdk/kivio_shape_data.h
+++ b/kivio/kiviopart/kiviosdk/kivio_shape_data.h
@@ -19,11 +19,11 @@
#ifndef KIVIO_SHAPE_DATA_H
#define KIVIO_SHAPE_DATA_H
-#include <qfont.h>
-#include <qcolor.h>
-#include <qdom.h>
-#include <qptrlist.h>
-#include <qstring.h>
+#include <tqfont.h>
+#include <tqcolor.h>
+#include <tqdom.h>
+#include <tqptrlist.h>
+#include <tqstring.h>
#include "kivio_point.h"
@@ -36,11 +36,11 @@ class KivioTextShapeData
public:
KivioTextShapeData();
- QString m_text; // The text inside this shape
- QColor m_textColor; // The text color
- QFont m_textFont; // The text font
+ TQString m_text; // The text inside this tqshape
+ TQColor m_textColor; // The text color
+ TQFont m_textFont; // The text font
bool m_isHtml; // Is the text HTML formatted?
- int m_hTextAlign, m_vTextAlign; // Horizontal and vertical text alignment flags
+ int m_hTextAlign, m_vTextAlign; //Qt::Horizontal and vertical text tqalignment flags
};
/**
@@ -52,7 +52,7 @@ class KivioShapeData
{
public:
/**
* The possible shape types.
*/
typedef enum {
kstNone = 0,
@@ -73,17 +73,17 @@ public:
protected:
friend class KivioShape;
- QPtrList <KivioPoint> *m_pOriginalPointList; // Original point list loaded from an SML file
+ TQPtrList <KivioPoint> *m_pOriginalPointList; // Original point list loaded from an SML file
- KivioShapeType m_shapeType; // The shape type
+ KivioShapeType m_tqshapeType; // The tqshape type
KivioPoint m_position, m_dimensions; // The position and dimensions
KivioFillStyle *m_pFillStyle; // The fill style
// QColor m_fgColor; // The foreground color
// float m_lineWidth; // The line width
KivioLineStyle *m_pLineStyle;
- QString m_name; // The name of this shape
+ TQString m_name; // The name of this tqshape
KivioTextStyle *m_pTextData; // A pointer to text data (if applicable, e.g. TextBox)
@@ -94,24 +94,24 @@ public:
virtual void copyInto( KivioShapeData *pTarget ) const;
- virtual bool loadXML( const QDomElement & );
- virtual QDomElement saveXML( QDomDocument & );
+ virtual bool loadXML( const TQDomElement & );
+ virtual TQDomElement saveXML( TQDomDocument & );
- KivioShapeType shapeType() const { return m_shapeType; }
+ KivioShapeType tqshapeType() const { return m_tqshapeType; }
void setShapeType( KivioShapeType st );
- static KivioShapeType shapeTypeFromString( const QString & );
+ static KivioShapeType tqshapeTypeFromString( const TQString & );
- QPtrList<KivioPoint> *pointList() { return m_pOriginalPointList; }
+ TQPtrList<KivioPoint> *pointList() { return m_pOriginalPointList; }
KivioFillStyle *fillStyle() const { return m_pFillStyle; }
KivioLineStyle *lineStyle() const { return m_pLineStyle; }
void setLineStyle(KivioLineStyle ls);
- const QString &name() const { return m_name; }
- void setName( const QString &newName ) { m_name=newName; }
+ const TQString &name() const { return m_name; }
+ void setName( const TQString &newName ) { m_name=newName; }
// Dimensions / Position
@@ -126,8 +126,8 @@ public:
// Text functions
- QString text();
- void setText( const QString &newText );
+ TQString text();
+ void setText( const TQString &newText );
bool isHtml() const;
void setIsHtml( bool b );
@@ -138,11 +138,11 @@ public:
int vTextAlign() const;
void setVTextAlign( int i );
- QFont textFont();
- void setTextFont( const QFont &f );
+ TQFont textFont();
+ void setTextFont( const TQFont &f );
- QColor textColor();
- void setTextColor( QColor c );
+ TQColor textColor();
+ void setTextColor( TQColor c );
void setTextStyle( KivioTextStyle * );
};
@@ -52,7 +52,7 @@ class KivioShapeData
public:
/**
- * The possible shape types.
+ * The possible tqshape types.
*/
typedef enum {
@@ -73,17 +73,17 @@ public:
KivioPoint m_position, m_dimensions; // The position and dimensions
KivioFillStyle *m_pFillStyle; // The fill style
-// QColor m_fgColor; // The foreground color
+// TQColor m_fgColor; // The foreground color
// float m_lineWidth; // The line width
KivioLineStyle *m_pLineStyle;